@@ -36,6 +36,7 @@ void ContentTest::testGetHeaderInstance()
     QCOMPARE(myfrom->type(), "From");
     Headers::Base *mybase = myfrom;
     QCOMPARE(mybase->type(), "From");
+    delete myfrom;
 
     // getHeaderInstance() is protected, so we need to test it via KMime::Message
     Message *c = new Message();
@@ -83,15 +84,28 @@ void ContentTest::testHeaderAddRemove()
     c->assemble();
     QVERIFY(c->head().isEmpty());
     QVERIFY(!c->contentDescription(false));
+
+    delete c;
+
+    // test template versions
+    Content c2;
+    QVERIFY(!c2.hasHeader(KMime::Headers::Lines::staticType()));
+    QVERIFY(!c2.header<KMime::Headers::Lines>(false));
+    QVERIFY(c2.header<KMime::Headers::Lines>(true));
+    QVERIFY(c2.hasHeader(KMime::Headers::Lines::staticType()));
+    c2.removeHeader<KMime::Headers::Lines>();
+    QVERIFY(!c2.hasHeader(KMime::Headers::Lines::staticType()));
 }
 
-void ContentTest::testHeaderAppendPrepend()
+void ContentTest::testHeaderAppend()
 {
     Content *c = new Content;
     QByteArray d1("Resent-From: test1@example.com");
     QByteArray d2("Resent-From: test2@example.com");
-    Headers::Generic *h1 = new Headers::Generic("Resent-From", 0, "test1@example.com");
-    Headers::Generic *h2 = new Headers::Generic("Resent-From", 0, "test2@example.com");
+    Headers::Generic *h1 = new Headers::Generic("Resent-From");
+    h1->from7BitString("test1@example.com");
+    Headers::Generic *h2 = new Headers::Generic("Resent-From");
+    h2->from7BitString("test2@example.com");
     c->appendHeader(h1);
     c->appendHeader(h2);
     c->assemble();
@@ -99,11 +113,13 @@ void ContentTest::testHeaderAppendPrepend()
     QCOMPARE(c->head(), head);
 
     QByteArray d3("Resent-From: test3@example.com");
-    Headers::Generic *h3 = new Headers::Generic("Resent-From", 0, "test3@example.com");
-    c->prependHeader(h3);
+    Headers::Generic *h3 = new Headers::Generic("Resent-From");
+    h3->from7BitString("test3@example.com");
+    c->appendHeader(h3);
     c->assemble();
-    head.prepend(d3 + '\n');
+    head.append(d3 + '\n');
     QCOMPARE(c->head(), head);
+    delete c;
 }
 
 void ContentTest::testImplicitMultipartGeneration()
@@ -196,13 +212,6 @@ void ContentTest::testSetContent()
     QCOMPARE(c->head(), QByteArray("head1\nhead2\n"));
     QCOMPARE(c->body(), QByteArray("body1\n\nbody2\n"));
 
-    QList<QByteArray> list;
-    list << "head1" << "head2" << "" << "body1" << "" << "body2";
-    c->setContent(list);
-    QVERIFY(c->hasContent());
-    QCOMPARE(c->head(), QByteArray("head1\nhead2\n"));
-    QCOMPARE(c->body(), QByteArray("body1\n\nbody2\n"));     // ### the final \n is questionable
-
     // empty content
     c->setContent(QByteArray());
     QVERIFY(!c->hasContent());
@@ -215,25 +224,13 @@ void ContentTest::testSetContent()
     QVERIFY(c->head().isEmpty());
     QCOMPARE(c->body(), QByteArray("body1\n\nbody2\n"));
 
-    list.clear();
-    list << "" << "body1" << "" << "body2";
-    c->setContent(list);
-    QVERIFY(c->hasContent());
-    QVERIFY(c->head().isEmpty());
-    QCOMPARE(c->body(), QByteArray("body1\n\nbody2\n"));
-
     // empty body
     c->setContent("head1\nhead2\n\n");
     QVERIFY(c->hasContent());
     QCOMPARE(c->head(), QByteArray("head1\nhead2\n"));
     QVERIFY(c->body().isEmpty());
 
-    list.clear();
-    list << "head1" << "head2" << "";
-    c->setContent(list);
-    QVERIFY(c->hasContent());
-    QCOMPARE(c->head(), QByteArray("head1\nhead2\n"));
-    QVERIFY(c->body().isEmpty());
+    delete c;
 }
 
 void ContentTest::testEncodedContent()
@@ -325,6 +322,7 @@ void ContentTest::testDecodedContent()
     QVERIFY(c->decodedContent() == QByteArray());
     c->setBody(" ");
     QVERIFY(c->decodedContent() == QByteArray(" "));
+    delete c;
 }
 
 void ContentTest::testMultipleHeaderExtraction()
@@ -346,11 +344,12 @@ void ContentTest::testMultipleHeaderExtraction()
     //  QCOMPARE( msg->encodedContent(), data );
     msg->parse();
 
-    QList<KMime::Headers::Base *> result = msg->headersByType("Received");
+    auto result = msg->headersByType("Received");
     QCOMPARE(result.count(), 3);
     QCOMPARE(result[0]->asUnicodeString(),  QString::fromLatin1("from ktown.kde.org ([192.168.100.1])"));
     QCOMPARE(result[1]->asUnicodeString(),  QString::fromLatin1("from dev1.kde.org ([192.168.100.2]) by ktown.kde.org ([192.168.100.1])"));
     QCOMPARE(result[2]->asUnicodeString(),  QString::fromLatin1("from dev2.kde.org ([192.168.100.3]) by ktown.kde.org ([192.168.100.1])"));
+    delete msg;
 }
 
 void ContentTest::testMultipartMixed()
@@ -425,6 +424,7 @@ void ContentTest::testMultipartMixed()
         "Subject: Sample message\n"
         "MIME-Version: 1.0\n"
         "Content-Type: multipart/mixed; boundary=\"simple boundary\"\n"
+        "Content-Transfer-Encoding: 7Bit\n"
         "\n"
         "--simple boundary\n"
         "\n"
@@ -445,7 +445,7 @@ void ContentTest::testMultipartMixed()
     msg->parse();
     QVERIFY(msg->contentType()->isMultipart());
 
-    Content::List list = msg->contents();
+    auto list = msg->contents();
     QCOMPARE(list.count(), 2);
     Content *c = list.takeFirst();
     QCOMPARE(c->body(), part1);
@@ -467,7 +467,9 @@ void ContentTest::testMultipartMixed()
     msg->date()->from7BitString("Sun, 21 Mar 1993 23:56:48 -0800 (PST)");
     msg->subject()->from7BitString("Sample message");
     // HACK to make MIME-Version appear before Content-Type, as in the expected message.
-    msg->setHeader(new Headers::MIMEVersion(msg, "1.234"));
+    auto header = new Headers::MIMEVersion;
+    header->from7BitString("1.234");
+    msg->setHeader(header);
     msg->setBody(part1);
     c = new Content();
     c->setBody(part2);
@@ -488,6 +490,7 @@ void ContentTest::testMultipartMixed()
     //qDebug() << "expected assembled content" << assembled;
     //qDebug() << "actual encoded content" << encc;
     QCOMPARE(msg->encodedContent(), assembled);
+    delete msg;
 }
 
 void ContentTest::testParsingUuencoded()
@@ -585,7 +588,7 @@ void ContentTest::testParsingUuencoded()
     Message *msg = new Message();
     msg->setContent(uuencodedMsg);
     msg->parse();
-    Content::List contents = msg->contents();
+    auto contents = msg->contents();
 
     // text + image
     QCOMPARE(contents.size(), 2);
@@ -684,6 +687,10 @@ void ContentTest::testParent()
     QCOMPARE(msg->contents().at(0)->parent(), msg);
     QCOMPARE(msg->contents().at(1)->parent(), msg);
     delete msg;
+
+    delete c1;
+    delete c2;
+    delete c5;
 }
 
 void ContentTest::testFreezing()
@@ -733,5 +740,6 @@ void ContentTest::testFreezing()
     // Calling assemble() should not alter the data.
     msg->assemble();
     QCOMPARE(msg->encodedContent(), data);
+    delete msg;
 }
 
