@@ -56,7 +56,7 @@ void HeaderTest::testIdentHeader()
     h = new Headers::Generics::Ident();
     h->from7BitString(QByteArray("<1234@local.machine.example> <3456@example.net>"));
     QCOMPARE(h->identifiers().count(), 2);
-    QList<QByteArray> ids = h->identifiers();
+    auto ids = h->identifiers();
     QCOMPARE(ids.takeFirst(), QByteArray("1234@local.machine.example"));
     QCOMPARE(ids.first(), QByteArray("3456@example.net"));
     delete h;
@@ -99,9 +99,9 @@ void HeaderTest::testAddressListHeader()
     QCOMPARE(h->addresses().count(), 1);
     QCOMPARE(h->addresses().first(), QByteArray("joe@where.test"));
     QCOMPARE(h->displayNames().count(), 1);
-    QCOMPARE(h->displayNames().first(), QString());
-    QCOMPARE(h->prettyAddresses().count(), 1);
-    QCOMPARE(h->prettyAddresses().first(), QLatin1String("joe@where.test"));
+    QCOMPARE(h->displayNames().first(), QLatin1String("joe@where.test"));
+    QCOMPARE(h->displayString(), QLatin1String("joe@where.test"));
+    QCOMPARE(h->asUnicodeString(), QLatin1String("joe@where.test"));
 
     // clearing a header
     h->clear();
@@ -114,7 +114,8 @@ void HeaderTest::testAddressListHeader()
     QCOMPARE(h->addresses().count(), 1);
     QCOMPARE(h->addresses().first(), QByteArray("pete@silly.example"));
     QCOMPARE(h->displayNames().first(), QLatin1String("Pete"));
-    QCOMPARE(h->prettyAddresses().first(), QLatin1String("Pete <pete@silly.example>"));
+    QCOMPARE(h->displayString(), QLatin1String("Pete"));
+    QCOMPARE(h->asUnicodeString(), QLatin1String("Pete <pete@silly.example>"));
     QCOMPARE(h->as7BitString(false), QByteArray("Pete <pete@silly.example>"));
     delete h;
 
@@ -124,7 +125,7 @@ void HeaderTest::testAddressListHeader()
     QCOMPARE(h->addresses().count(), 1);
     QCOMPARE(h->addresses().first(), QByteArray("jdoe@machine.example"));
     QCOMPARE(h->displayNames().first(), QLatin1String("John Doe"));
-    QCOMPARE(h->prettyAddresses().first(), QLatin1String("John Doe <jdoe@machine.example>"));
+    QCOMPARE(h->asUnicodeString(), QLatin1String("John Doe <jdoe@machine.example>"));
     delete h;
 
     // parsing and re-assembling list of diffrent addresses
@@ -133,8 +134,9 @@ void HeaderTest::testAddressListHeader()
     QCOMPARE(h->addresses().count(), 3);
     QStringList names = h->displayNames();
     QCOMPARE(names.takeFirst(), QLatin1String("Mary Smith"));
-    QCOMPARE(names.takeFirst(), QString());
+    QCOMPARE(names.takeFirst(), QLatin1String("jdoe@example.org"));
     QCOMPARE(names.takeFirst(), QLatin1String("Who?"));
+    QCOMPARE(h->displayString(), QLatin1String("Mary Smith, jdoe@example.org, Who?"));
     QCOMPARE(h->as7BitString(false), QByteArray("Mary Smith <mary@x.test>, jdoe@example.org, Who? <one@y.test>"));
     delete h;
 
@@ -144,7 +146,7 @@ void HeaderTest::testAddressListHeader()
     QCOMPARE(h->addresses().count(), 3);
     names = h->displayNames();
     QCOMPARE(names.takeFirst(), QLatin1String("Joe Q. Public"));
-    QCOMPARE(names.takeFirst(), QString());
+    QCOMPARE(names.takeFirst(), QLatin1String("boss@nil.test"));
     QCOMPARE(names.takeFirst(), QLatin1String("Giant; \"Big\" Box"));
     QCOMPARE(h->as7BitString(false), QByteArray("\"Joe Q. Public\" <john.q.public@example.com>, boss@nil.test, \"Giant; \\\"Big\\\" Box\" <sysservices@example.net>"));
     delete h;
@@ -196,7 +198,7 @@ void HeaderTest::testAddressListHeader()
     QCOMPARE(h->addresses().count(), 3);
     names = h->displayNames();
     QCOMPARE(names.takeFirst(), QLatin1String("Chris Jones"));
-    QCOMPARE(names.takeFirst(), QString());
+    QCOMPARE(names.takeFirst(), QLatin1String("joe@where.test"));
     QCOMPARE(names.takeFirst(), QLatin1String("John"));
     QCOMPARE(h->as7BitString(false), QByteArray("Chris Jones <c@a.test>, joe@where.test, John <jdoe@one.test>"));
     delete h;
@@ -225,26 +227,29 @@ void HeaderTest::testAddressListHeader()
     h->from7BitString("Vice@censored.serverkompetenz.net,\n    President@mail2.censored.net;\"Int\\\\\\\\\\\\\\\\\\\\'l\" Lotto Commission. <censored@yahoo.fr>");
     QCOMPARE(h->addresses().count(), 3);
     names = h->displayNames();
-    QCOMPARE(names.takeFirst(), QString());
-    QCOMPARE(names.takeFirst(), QString());
+    QCOMPARE(names.takeFirst(), QLatin1String("Vice@censored.serverkompetenz.net"));
+    QCOMPARE(names.takeFirst(), QLatin1String("President@mail2.censored.net"));
     // there is an wrong ' ' after the name, but since the header is completely
     // broken we can be happy it parses at all...
     QCOMPARE(names.takeFirst(), QLatin1String("Int\\\\\\\\\\'l Lotto Commission. "));
-    QList<QByteArray> addrs = h->addresses();
+    auto addrs = h->addresses();
     QCOMPARE(addrs.takeFirst(), QByteArray("Vice@censored.serverkompetenz.net"));
     QCOMPARE(addrs.takeFirst(), QByteArray("President@mail2.censored.net"));
     QCOMPARE(addrs.takeFirst(), QByteArray("censored@yahoo.fr"));
     delete h;
 
     // based on bug #102010, a display name containing '<'
-    h = new Headers::Generics::AddressList(0, QByteArray("\"|<onrad\" <censored@censored.dy>"));
+    h = new Headers::Generics::AddressList();
+    h->from7BitString("\"|<onrad\" <censored@censored.dy>");
     QCOMPARE(h->addresses().count(), 1);
     QCOMPARE(h->addresses().first(), QByteArray("censored@censored.dy"));
     QCOMPARE(h->displayNames().first(), QLatin1String("|<onrad"));
     QCOMPARE(h->as7BitString(false), QByteArray("\"|<onrad\" <censored@censored.dy>"));
+    delete h;
 
     // based on bug #93790 (legacy display name with nested comments)
-    h = new Headers::Generics::AddressList(0, QByteArray("first.name@domain.tld (first name (nickname))"));
+    h = new Headers::Generics::AddressList();
+    h->from7BitString("first.name@domain.tld (first name (nickname))");
     QCOMPARE(h->displayNames().count(), 1);
     QCOMPARE(h->displayNames().first(), QLatin1String("first name (nickname)"));
     QCOMPARE(h->as7BitString(false), QByteArray("\"first name (nickname)\" <first.name@domain.tld>"));
@@ -259,13 +264,15 @@ void HeaderTest::testAddressListHeader()
     delete h;
 
     // corner case of almost-rfc2047 encoded string in quoted string but not
-    h = new Headers::Generics::AddressList(0, QByteArray("\"Some =Use ?r\" <user@example.com>"));
+    h = new Headers::Generics::AddressList();
+    h->from7BitString("\"Some =Use ?r\" <user@example.com>");
     QCOMPARE(h->mailboxes().count(), 1);
     QCOMPARE(h->as7BitString(false), QByteArray("\"Some =Use ?r\" <user@example.com>"));
     delete h;
 
     // corner case of almost-rfc2047 encoded string in quoted string but not
-    h = new Headers::Generics::AddressList(0, QByteArray("\"Some ?=U=?se =?r\" <user@example.com>"));
+    h = new Headers::Generics::AddressList();
+    h->from7BitString("\"Some ?=U=?se =?r\" <user@example.com>");
     QCOMPARE(h->mailboxes().count(), 1);
     QCOMPARE(h->as7BitString(false), QByteArray("\"Some ?=U=?se =?r\" <user@example.com>"));
     delete h;
@@ -277,9 +284,8 @@ void HeaderTest::testAddressListHeader()
     QCOMPARE(h->addresses().count(), 1);
     QCOMPARE(h->addresses().first(), QByteArray("joe@where.test."));
     QCOMPARE(h->displayNames().count(), 1);
-    QCOMPARE(h->displayNames().first(), QString());
-    QCOMPARE(h->prettyAddresses().count(), 1);
-    QCOMPARE(h->prettyAddresses().first(), QLatin1String("joe@where.test."));
+    QCOMPARE(h->displayNames().first(), QLatin1String("joe@where.test."));
+    QCOMPARE(h->asUnicodeString(), QLatin1String("joe@where.test."));
     delete h;
 
     h = new Headers::Generics::AddressList();
@@ -287,7 +293,7 @@ void HeaderTest::testAddressListHeader()
     QCOMPARE(h->addresses().count(), 3);
     names = h->displayNames();
     QCOMPARE(names.takeFirst(), QLatin1String("Mary Smith"));
-    QCOMPARE(names.takeFirst(), QString());
+    QCOMPARE(names.takeFirst(), QLatin1String("jdoe@example.org."));
     QCOMPARE(names.takeFirst(), QLatin1String("Who?"));
     QCOMPARE(h->as7BitString(false), QByteArray("Mary Smith <mary@x.test>, jdoe@example.org., Who? <one@y.test>"));
     delete h;
@@ -306,15 +312,16 @@ void HeaderTest::testMailboxListHeader()
     QCOMPARE(h->addresses().count(), 1);
     QCOMPARE(h->addresses().first(), QByteArray("joe_smith@where.test"));
     QCOMPARE(h->displayNames().count(), 1);
-    QCOMPARE(h->displayNames().first(), QString());
-    QCOMPARE(h->prettyAddresses().count(), 1);
-    QCOMPARE(h->prettyAddresses().first(), QLatin1String("joe_smith@where.test"));
+    QCOMPARE(h->displayNames().first(), QLatin1String("joe_smith@where.test"));
+    QCOMPARE(h->displayString(), QLatin1String("joe_smith@where.test"));
+    QCOMPARE(h->asUnicodeString(), QLatin1String("joe_smith@where.test"));
 
     // https://bugzilla.novell.com/show_bug.cgi?id=421057 (but apparently this was not the cause of the bug)
     h->from7BitString("fr...@ce.sco (Francesco)");
     QVERIFY(!h->isEmpty());
     QCOMPARE(h->mailboxes().count(), 1);
-    QCOMPARE(h->prettyAddresses().first(), QLatin1String("Francesco <fr...@ce.sco>"));
+    QCOMPARE(h->displayString(), QLatin1String("Francesco"));
+    QCOMPARE(h->asUnicodeString(), QLatin1String("Francesco <fr...@ce.sco>"));
 
     delete h;
 }
@@ -331,9 +338,8 @@ void HeaderTest::testSingleMailboxHeader()
     QCOMPARE(h->addresses().count(), 1);
     QCOMPARE(h->addresses().first(), QByteArray("joe_smith@where.test"));
     QCOMPARE(h->displayNames().count(), 1);
-    QCOMPARE(h->displayNames().first(), QString());
-    QCOMPARE(h->prettyAddresses().count(), 1);
-    QCOMPARE(h->prettyAddresses().first(), QLatin1String("joe_smith@where.test"));
+    QCOMPARE(h->displayNames().first(), QLatin1String("joe_smith@where.test"));
+    QCOMPARE(h->asUnicodeString(), QLatin1String("joe_smith@where.test"));
 
     // parse single simple address with display name
     h->from7BitString("John Smith <joe_smith@where.test>");
@@ -342,8 +348,7 @@ void HeaderTest::testSingleMailboxHeader()
     QCOMPARE(h->addresses().first(), QByteArray("joe_smith@where.test"));
     QCOMPARE(h->displayNames().count(), 1);
     QCOMPARE(h->displayNames().first(), QLatin1String("John Smith"));
-    QCOMPARE(h->prettyAddresses().count(), 1);
-    QCOMPARE(h->prettyAddresses().first(), QLatin1String("John Smith <joe_smith@where.test>"));
+    QCOMPARE(h->asUnicodeString(), QLatin1String("John Smith <joe_smith@where.test>"));
     QCOMPARE(h->mailboxes().first().prettyAddress(Types::Mailbox::QuoteAlways),
              QLatin1String("\"John Smith\" <joe_smith@where.test>"));
 
@@ -420,38 +425,44 @@ void HeaderTest::testMailCopiesToHeader()
     delete h;
 
     // parse copy to poster
-    h = new MailCopiesTo(0, "always");
+    h = new MailCopiesTo;
+    h->from7BitString("always");
     QVERIFY(h->addresses().isEmpty());
     QVERIFY(!h->isEmpty());
     QVERIFY(h->alwaysCopy());
     delete h;
 
-    h = new MailCopiesTo(0, "poster");
+    h = new MailCopiesTo;
+    h->from7BitString("poster");
     QVERIFY(h->addresses().isEmpty());
     QVERIFY(!h->isEmpty());
     QVERIFY(h->alwaysCopy());
     delete h;
 
     // parse never copy
-    h = new MailCopiesTo(0, "never");
+    h = new MailCopiesTo;
+    h->from7BitString("never");
     QVERIFY(h->addresses().isEmpty());
     QVERIFY(!h->isEmpty());
     QVERIFY(h->neverCopy());
     delete h;
 
-    h = new MailCopiesTo(0, "nobody");
+    h = new MailCopiesTo;
+    h->from7BitString("nobody");
     QVERIFY(h->addresses().isEmpty());
     QVERIFY(!h->isEmpty());
     QVERIFY(h->neverCopy());
     delete h;
 
     // parsing is case-insensitive
-    h = new MailCopiesTo(0, "AlWays");
+    h = new MailCopiesTo;
+    h->from7BitString("AlWays");
     QVERIFY(h->alwaysCopy());
     delete h;
 
     // parse address
-    h = new MailCopiesTo(0, "vkrause@kde.org");
+    h = new MailCopiesTo;
+    h->from7BitString("vkrause@kde.org");
     QVERIFY(!h->addresses().isEmpty());
     QVERIFY(h->alwaysCopy());
     QVERIFY(!h->neverCopy());
@@ -483,7 +494,8 @@ void HeaderTest::testParametrizedHeader()
     delete h;
 
     // parse a parameter list
-    h = new Parametrized(0, "filename=genome.jpeg;\n modification-date=\"Wed, 12 Feb 1997 16:29:51 -0500\"");
+    h = new Parametrized;
+    h->from7BitString("filename=genome.jpeg;\n modification-date=\"Wed, 12 Feb 1997 16:29:51 -0500\"");
     QCOMPARE(h->parameter(QLatin1String("filename")), QLatin1String("genome.jpeg"));
     QCOMPARE(h->parameter(QLatin1String("modification-date")), QLatin1String("Wed, 12 Feb 1997 16:29:51 -0500"));
     QCOMPARE(h->as7BitString(false), QByteArray("filename=\"genome.jpeg\"; modification-date=\"Wed, 12 Feb 1997 16:29:51 -0500\""));
@@ -517,14 +529,16 @@ void HeaderTest::testContentDispositionHeader()
     delete h;
 
     // parse parameter-less header
-    h = new ContentDisposition(0, "inline");
+    h = new ContentDisposition;
+    h->from7BitString("inline");
     QCOMPARE(h->disposition(), CDinline);
     QVERIFY(h->filename().isEmpty());
     QCOMPARE(h->as7BitString(true), QByteArray("Content-Disposition: inline"));
     delete h;
 
     // parse header with parameter
-    h = new ContentDisposition(0, "attachment; filename=genome.jpeg;\n modification-date=\"Wed, 12 Feb 1997 16:29:51 -0500\";");
+    h = new ContentDisposition;
+    h->from7BitString("attachment; filename=genome.jpeg;\n modification-date=\"Wed, 12 Feb 1997 16:29:51 -0500\";");
     QCOMPARE(h->disposition(), CDattachment);
     QCOMPARE(h->filename(), QLatin1String("genome.jpeg"));
     delete h;
@@ -569,26 +583,30 @@ void HeaderTest::testContentTypeHeader()
     delete h;
 
     // parse a complete header
-    h = new ContentType(0, "text/plain; charset=us-ascii (Plain text)");
+    h = new ContentType;
+    h->from7BitString("text/plain; charset=us-ascii (Plain text)");
     QVERIFY(h->isPlainText());
     QCOMPARE(h->charset(), QByteArray("us-ascii"));
     delete h;
 
     // bug #136631 (name with rfc 2231 style parameter wrapping)
-    h = new ContentType(0, "text/plain;\n name*0=\"PIN_Brief_box1@xx.xxx.censored_Konfigkarte.confi\";\n name*1=\"guration.txt\"");
+    h = new ContentType;
+    h->from7BitString("text/plain;\n name*0=\"PIN_Brief_box1@xx.xxx.censored_Konfigkarte.confi\";\n name*1=\"guration.txt\"");
     QVERIFY(h->isPlainText());
     QCOMPARE(h->name(), QLatin1String("PIN_Brief_box1@xx.xxx.censored_Konfigkarte.configuration.txt"));
     delete h;
 
     // bug #197958 (name of Content-Type sent by Mozilla Thunderbird are not parsed -- test case generated with v2.0.0.22)
-    h = new ContentType(0, "text/plain;\n name=\"=?ISO-8859-1?Q?lor=E9m_ipsum=2Etxt?=\"");
+    h = new ContentType;
+    h->from7BitString("text/plain;\n name=\"=?ISO-8859-1?Q?lor=E9m_ipsum=2Etxt?=\"");
     QCOMPARE(h->name(), QString::fromUtf8("lorém ipsum.txt"));
     delete h;
 
     // bug #197958 (name of Content-Type sent by Mozilla Thunderbird are not parsed -- test case generated with v2.0.0.22)
     // But with unquoted string
     QEXPECT_FAIL("", "Unqouted rfc2047 strings are not supported as of now", Continue);
-    h = new ContentType(0, "text/plain;\n name==?ISO-8859-1?Q?lor=E9m_ipsum=2Etxt?=");
+    h = new ContentType;
+    h->from7BitString("text/plain;\n name==?ISO-8859-1?Q?lor=E9m_ipsum=2Etxt?=");
     QCOMPARE(h->name(), QString::fromUtf8("lorém ipsum.txt"));
     delete h;
 
@@ -627,7 +645,8 @@ void HeaderTest::testTokenHeader()
     delete h;
 
     // parse a header
-    h = new Token(0, "value (comment)");
+    h = new Token;
+    h->from7BitString("value (comment)");
     QCOMPARE(h->token(), QByteArray("value"));
     QCOMPARE(h->as7BitString(false), QByteArray("value"));
     delete h;
@@ -652,7 +671,8 @@ void HeaderTest::testContentTransferEncoding()
     delete h;
 
     // parse a header
-    h = new ContentTransferEncoding(0, "(comment) base64");
+    h = new ContentTransferEncoding;
+    h->from7BitString("(comment) base64");
     QCOMPARE(h->encoding(), CEbase64);
     QCOMPARE(h->as7BitString(false), QByteArray("base64"));
     delete h;
@@ -668,7 +688,8 @@ void HeaderTest::testPhraseListHeader()
     delete h;
 
     // parse a simple phrase list
-    h = new PhraseList(0, "foo,\n bar");
+    h = new PhraseList;
+    h->from7BitString("foo,\n bar");
     QVERIFY(!h->isEmpty());
     QCOMPARE(h->phrases().count(), 2);
     QStringList phrases = h->phrases();
@@ -727,7 +748,8 @@ void HeaderTest::testDateHeader()
     delete h;
 
     // white spaces and comment (from RFC 2822, Appendix A.5)
-    h = new Date(0, "Thu,\n  13\n    Feb\n  1969\n  23:32\n  -0330 (Newfoundland Time)");
+    h = new Date;
+    h->from7BitString("Thu,\n  13\n    Feb\n  1969\n  23:32\n  -0330 (Newfoundland Time)");
     QVERIFY(!h->isEmpty());
     QCOMPARE(h->dateTime().date(), QDate(1969, 2, 13));
     QCOMPARE(h->dateTime().time(), QTime(23, 32));
@@ -736,7 +758,8 @@ void HeaderTest::testDateHeader()
     delete h;
 
     // obsolete date format (from RFC 2822, Appendix A.6.2)
-    h = new Date(0, "21 Nov 97 09:55:06 GMT");
+    h = new Date;
+    h->from7BitString("21 Nov 97 09:55:06 GMT");
     QVERIFY(!h->isEmpty());
     QCOMPARE(h->dateTime().date(), QDate(1997, 11, 21));
     QCOMPARE(h->dateTime().time(), QTime(9, 55, 6));
@@ -744,7 +767,8 @@ void HeaderTest::testDateHeader()
     delete h;
 
     // obsolete whitespaces and commnets (from RFC 2822, Appendix A.6.3)
-    h = new Date(0, "Fri, 21 Nov 1997 09(comment):   55  :  06 -0600");
+    h = new Date;
+    h->from7BitString("Fri, 21 Nov 1997 09(comment):   55  :  06 -0600");
     QVERIFY(!h->isEmpty());
     QCOMPARE(h->dateTime().date(), QDate(1997, 11, 21));
     QCOMPARE(h->dateTime().time(), QTime(9, 55, 6));
@@ -752,7 +776,8 @@ void HeaderTest::testDateHeader()
     delete h;
 
     // Make sure uppercase OCT is parsed correctly - bug 150620
-    h = new Date(0, "08 OCT 08 16:54:05 +0000");
+    h = new Date;
+    h->from7BitString("08 OCT 08 16:54:05 +0000");
     QVERIFY(!h->isEmpty());
     QCOMPARE(h->dateTime().date(), QDate(2008, 10, 8));
     QCOMPARE(h->dateTime().time(), QTime(16, 54, 05));
@@ -760,7 +785,8 @@ void HeaderTest::testDateHeader()
     delete h;
 
     // Test for bug 111633, year < 1970
-    h = new Date(0, "Mon, 27 Aug 1956 21:31:46 +0200");
+    h = new Date;
+    h->from7BitString("Mon, 27 Aug 1956 21:31:46 +0200");
     QVERIFY(!h->isEmpty());
     QCOMPARE(h->dateTime().date(), QDate(1956, 8, 27));
     QCOMPARE(h->dateTime().time(), QTime(21, 31, 46));
@@ -768,7 +794,8 @@ void HeaderTest::testDateHeader()
     delete h;
 
     // Test for bug 207766
-    h = new Date(0, "Fri, 18 Sep 2009 04:44:55 -0400");
+    h = new Date;
+    h->from7BitString("Fri, 18 Sep 2009 04:44:55 -0400");
     QVERIFY(!h->isEmpty());
     QCOMPARE(h->dateTime().date(), QDate(2009, 9, 18));
     QCOMPARE(h->dateTime().time(), QTime(4, 44, 55));
@@ -776,7 +803,8 @@ void HeaderTest::testDateHeader()
     delete h;
 
     // Test for bug 260761
-    h = new Date(0, "Sat, 18 Dec 2010 14:01:21 \"GMT\"");
+    h = new Date;
+    h->from7BitString("Sat, 18 Dec 2010 14:01:21 \"GMT\"");
     QVERIFY(!h->isEmpty());
     QCOMPARE(h->dateTime().date(), QDate(2010, 12, 18));
     QCOMPARE(h->dateTime().time(), QTime(14, 1, 21));
@@ -784,14 +812,16 @@ void HeaderTest::testDateHeader()
     delete h;
 
     // old asctime()-like formatted date; regression to KDE3; see bug 117848
-    h = new Date(0, "Thu Mar 30 18:36:28 CEST 2006");
+    h = new Date;
+    h->from7BitString("Thu Mar 30 18:36:28 CEST 2006");
     QVERIFY(!h->isEmpty());
     QCOMPARE(h->dateTime().date(), QDate(2006, 3, 30));
     QCOMPARE(h->dateTime().time(), QTime(18, 36, 28));
     QCOMPARE(h->dateTime().utcOffset(), 2 * 3600);
     delete h;
 
-    h = new Date(0, "Thu Mar 30 18:36:28 2006");
+    h = new Date;
+    h->from7BitString("Thu Mar 30 18:36:28 2006");
     QVERIFY(!h->isEmpty());
     QCOMPARE(h->dateTime().date(), QDate(2006, 3, 30));
     QCOMPARE(h->dateTime().time(), QTime(18, 36, 28));
@@ -799,7 +829,8 @@ void HeaderTest::testDateHeader()
     delete h;
 
     // regression to KDE3; see bug 54098
-    h = new Date(0, "Tue, Feb 04, 2003 00:01:20 +0000");
+    h = new Date;
+    h->from7BitString("Tue, Feb 04, 2003 00:01:20 +0000");
     QVERIFY(!h->isEmpty());
     QCOMPARE(h->dateTime().date(), QDate(2003, 2, 4));
     QCOMPARE(h->dateTime().time(), QTime(0, 1, 20));
@@ -827,7 +858,8 @@ void HeaderTest::testLinesHeader()
     delete h;
 
     // parse header with comment
-    h = new Lines(0, "(this is a comment) 10 (and yet another comment)");
+    h = new Lines;
+    h->from7BitString("(this is a comment) 10 (and yet another comment)");
     QVERIFY(!h->isEmpty());
     QCOMPARE(h->numberOfLines(), 10);
     delete h;
@@ -843,7 +875,7 @@ void HeaderTest::testNewsgroupsHeader()
     QVERIFY(h->as7BitString().isEmpty());
 
     // set newsgroups
-    QList<QByteArray> groups;
+    QVector<QByteArray> groups;
     groups << "gmane.comp.kde.devel.core" << "gmane.comp.kde.devel.buildsystem";
     h->setGroups(groups);
     QVERIFY(!h->isEmpty());
@@ -855,7 +887,8 @@ void HeaderTest::testNewsgroupsHeader()
     delete h;
 
     // parse a header
-    h = new Newsgroups(0, "gmane.comp.kde.devel.core,gmane.comp.kde.devel.buildsystem");
+    h = new Newsgroups;
+    h->from7BitString("gmane.comp.kde.devel.core,gmane.comp.kde.devel.buildsystem");
     groups = h->groups();
     QCOMPARE(groups.count(), 2);
     QCOMPARE(groups.takeFirst(), QByteArray("gmane.comp.kde.devel.core"));
@@ -893,7 +926,8 @@ void HeaderTest::testControlHeader()
     delete h;
 
     // parse a control header
-    h = new Control(0, "cancel <foo@bar>");
+    h = new Control;
+    h->from7BitString("cancel <foo@bar>");
     QVERIFY(!h->isEmpty());
     QCOMPARE(h->parameter(), QByteArray("<foo@bar>"));
     QVERIFY(h->isCancel());
