@@ -21,6 +21,7 @@
 #include <qtest.h>
 #include <qdebug.h>
 #include <QFile>
+#include <kmime_codecs.cpp>
 
 using namespace KMime;
 
@@ -79,6 +80,10 @@ void MessageTest::testMainBodyPart()
     QCOMPARE(msg3->mainBodyPart(), html);
     QCOMPARE(msg3->mainBodyPart("text/plain"), text);
     QCOMPARE(msg3->mainBodyPart("text/html"), html);
+
+    delete msg2;
+    delete msg3;
+    delete attach;
 }
 
 void MessageTest::testBrunosMultiAssembleBug()
@@ -306,7 +311,7 @@ void MessageTest::testUtf16()
     QCOMPARE(msg.decodedText(false, true), QLatin1String("This is UTF-16 Text."));
 
     // Add a new To header, for testings
-    KMime::Headers::To *to = new KMime::Headers::To(&msg);
+    KMime::Headers::To *to = new KMime::Headers::To;
     KMime::Types::Mailbox address;
     address.setAddress("test@test.de");
     address.setName(QLatin1String("Fränz Töster"));
@@ -506,7 +511,7 @@ void MessageTest::testEncapsulatedMessages()
     QVERIFY(messageContent->body().isEmpty());
     QCOMPARE(messageContent->contents().count(), 1);
     QVERIFY(messageContent->bodyIsMessage());
-    QVERIFY(messageContent->bodyAsMessage().get());
+    QVERIFY(messageContent->bodyAsMessage().data());
     QVERIFY(!messageContent->isTopLevel());
     QCOMPARE(messageContent->index().toString().toLatin1().data(), "2");
 
@@ -518,11 +523,11 @@ void MessageTest::testEncapsulatedMessages()
     QCOMPARE(encapsulated->subject()->as7BitString(false).data(), "Foo");
     QCOMPARE(encapsulated->decodedText(false, false),
              QLatin1String("This is the encapsulated message body."));
-    QCOMPARE(encapsulated.get(), messageContent->bodyAsMessage().get());
-    QCOMPARE(encapsulated.get(), messageContent->contents().first());
+    QCOMPARE(encapsulated.data(), messageContent->bodyAsMessage().data());
+    QCOMPARE(encapsulated.data(), messageContent->contents().first());
     QCOMPARE(encapsulated->parent(), messageContent);
     QVERIFY(!encapsulated->isTopLevel());
-    QCOMPARE(encapsulated->topLevel(), msg.get());
+    QCOMPARE(encapsulated->topLevel(), msg.data());
     QCOMPARE(encapsulated->index().toString().toLatin1().data(), "2.1");
 
     // Now test some misc functions
@@ -551,7 +556,7 @@ void MessageTest::testEncapsulatedMessages()
     QCOMPARE(msg->contents().size(), 2);
     messageContent = msg->contents().at(1);
     QCOMPARE(messageContent->contentType()->mimeType().data(), "message/rfc822");
-    QVERIFY(encapsulated.get() == messageContent->bodyAsMessage().get());
+    QVERIFY(encapsulated.data() == messageContent->bodyAsMessage().data());
 
     // Setting a new body and then parsing it should discard the encapsulated message
     messageContent->contentType()->setMimeType("text/plain");
@@ -592,10 +597,11 @@ void MessageTest::testOutlookAttachmentNaming()
 void MessageTest::testEncryptedMails()
 {
     KMime::Message::Ptr msg = readAndParseMail(QLatin1String("x-pkcs7.mbox"));
-    QVERIFY(msg->attachments().count() == 1);
-    QVERIFY(KMime::isEncrypted(msg.get()) == true);
-    QVERIFY(KMime::isInvitation(msg.get()) == false);
-    QVERIFY(KMime::isSigned(msg.get()) == false);
+    QVERIFY(msg->contents().size() == 0);
+    QVERIFY(msg->attachments().count() == 0);
+    QVERIFY(KMime::isEncrypted(msg.data()) == true);
+    QVERIFY(KMime::isInvitation(msg.data()) == false);
+    QVERIFY(KMime::isSigned(msg.data()) == false);
 }
 
 void MessageTest::testReturnSameMail()
@@ -616,6 +622,13 @@ void MessageTest::testReturnSameMail()
     QCOMPARE(msg2.encodedContent(), fileContent);
 }
 
+void MessageTest::testEmptySubject()
+{
+    auto msg = readAndParseMail(QLatin1String("empty-subject.mbox"));
+    QVERIFY(msg); // was crashing for Andre
+    QVERIFY(msg->hasHeader("Subject"));
+    QVERIFY(msg->subject()->asUnicodeString().isEmpty());
+}
 
 KMime::Message::Ptr MessageTest::readAndParseMail(const QString &mailFile) const
 {
