@@ -25,8 +25,6 @@ class RFC2047Test : public QObject
 {
     Q_OBJECT
 private Q_SLOTS:
-    void testRFC2047decode();
-    void testInvalidDecode();
     void testRFC2047encode();
 };
 
