@@ -53,11 +53,11 @@ TODO: possible glossary terms:
 #include "kmime_util.h"
 #include "kmime_headers.h"
 
-#include <QtCore/QTextStream>
 #include <QtCore/QByteArray>
-#include <QtCore/QList>
+#include <QtCore/QVector>
+#include <QtCore/QSharedPointer>
+#include <QtCore/QMetaType>
 
-#include <boost/shared_ptr.hpp>
 
 namespace KMime
 {
@@ -116,38 +116,14 @@ public:
     /**
       Describes a list of Content objects.
     */
-    typedef QList<KMime::Content *> List;
-
-    /**
-      Creates an empty Content object.
-    */
-    Content();
+    typedef QVector<KMime::Content *> List;
 
     /**
       Creates an empty Content object with a specified parent.
       @param parent the parent Content object
       @since 4.3
     */
-    explicit Content(Content *parent);   // KDE5: Merge with the above.
-
-    /**
-      Creates a Content object containing the given raw data.
-
-      @param head is a QByteArray containing the header data.
-      @param body is a QByteArray containing the body data.
-    */
-    Content(const QByteArray &head, const QByteArray &body);
-
-    /**
-      Creates a Content object containing the given raw data.
-
-      @param head is a QByteArray containing the header data.
-      @param body is a QByteArray containing the body data.
-      @param parent the parent Content object
-      @since 4.3
-    */
-    // KDE5: Merge with the above.
-    Content(const QByteArray &head, const QByteArray &body, Content *parent);
+    explicit Content(Content *parent = Q_NULLPTR);
 
     /**
       Destroys this Content object.
@@ -159,18 +135,6 @@ public:
     */
     bool hasContent() const;
 
-    /**
-      Sets the Content to the given raw data, containing the Content head and
-      body separated by two linefeeds.
-
-      This method operates on the string representation of the Content. Call
-      parse() if you want to access individual headers, sub-Contents or the
-      encapsulated message.
-
-      @param l is a list of the raw Content data, split by lines.
-    */
-    void setContent(const QList<QByteArray> &l);
-
     /**
       Sets the Content to the given raw data, containing the Content head and
       body separated by two linefeeds.
@@ -204,7 +168,7 @@ public:
      *       Also, all old sub-contents will be deleted, so any old Content pointer will become
      *       invalid.
      */
-    virtual void parse();
+    void parse();
 
     /**
       Returns whether this Content is frozen.
@@ -244,13 +208,12 @@ public:
       signature verification, so you should *ONLY* call assemble() when you
       have actually modified the content.
     */
-    virtual void assemble();
+    void assemble();
 
     /**
       Clears the content, deleting all headers and sub-Contents.
     */
-    // KDE5: make non-virtual.
-    virtual void clear();
+    void clear();
 
     /**
       Removes all sub-Contents from this content.  Deletes them if @p del is true.
@@ -284,41 +247,13 @@ public:
     */
     void setHead(const QByteArray &head);
 
-    /**
-      Extracts and removes the next header from @p head.
-      The caller is responsible for deleting the returned header.
-
-      @deprecated Use KMime::HeaderParsing::extractFirstHeader().
-      @param head is a QByteArray containing the header data.
-    */
-    KMIME_DEPRECATED Headers::Generic *getNextHeader(QByteArray &head);
-
-    /**
-      Extracts and removes the next header from @p head.
-      The caller is responsible for deleting the returned header.
-      @since 4.2
-      @deprecated Use KMime::HeaderParsing::extractFirstHeader().
-      @param head is a QByteArray containing the header data.
-    */
-    // KDE5: Remove this. This method has nothing to do with *this object.
-    KMIME_DEPRECATED Headers::Generic *nextHeader(QByteArray &head);
-
-    /**
-      Tries to find a @p type header in the Content and returns it.
-      @param type the header type to find
-      @deprecated Use headerByType( const char * )
-    */
-    // KDE5: Make non-virtual.
-    KMIME_DEPRECATED virtual Headers::Base *getHeaderByType(const char *type);
-
     /**
       Returns the first header of type @p type, if it exists.  Otherwise returns 0.
       Note that the returned header may be empty.
       @param type the header type to find
       @since 4.2
     */
-    // KDE5: Make non-virtual.
-    virtual Headers::Base *headerByType(const char *type);
+    Headers::Base *headerByType(const char *type) const;
 
     /**
       Returns the first header of type T, if it exists.
@@ -339,7 +274,7 @@ public:
       @param type the header type to find
       @since 4.2
     */
-    virtual QList<Headers::Base *> headersByType(const char *type);
+    QVector<Headers::Base*> headersByType(const char *type) const;
 
     /**
       Sets the specified header to this Content.
@@ -352,8 +287,7 @@ public:
       @see removeHeader()
       @since 4.4
     */
-    // KDE5: make non-virtual.
-    virtual void setHeader(Headers::Base *h);
+    void setHeader(Headers::Base *h);
 
     /**
       Appends the specified header to the headers of this Content.
@@ -362,30 +296,29 @@ public:
     */
     void appendHeader(Headers::Base *h);
 
-    /**
-      Prepends the specified header to the headers of this Content.
-      @param h The header to prepend.
-      @since 4.4
-    */
-    void prependHeader(Headers::Base *h);
-
     /**
       Searches for the first header of type @p type, and deletes it, removing
       it from this Content.
       @param type The type of the header to look for.
       @return true if a header was found and removed.
     */
-    // TODO probably provide removeHeader<T>() too.
-    // KDE5: make non-virtual.
-    virtual bool removeHeader(const char *type);
+    bool removeHeader(const char *type);
+
+    /**
+      Searches for the first header of type @p T, and deletes it, removing
+      it from this Content.
+      @tparam T The type of the header to look for.
+      @return true if a header was found and removed.
+    */
+    template <typename T> bool removeHeader();
+
 
     /**
       @return true if this Content has a header of type @p type.
       @param type The type of the header to look for.
     */
     // TODO probably provide hasHeader<T>() too.
-    // TODO: KDE5: make const
-    bool hasHeader(const char *type);
+    bool hasHeader(const char *type) const;
 
     /**
       Returns the Content-Type header.
@@ -585,18 +518,19 @@ public:
     Content *textContent();
 
     /**
-      Returns a list of attachments.
-
-      @param incAlternatives If true, include multipart/alternative parts.
-    */
-    List attachments(bool incAlternatives = false);
+     * Returns all attachments below this node, recursively.
+     * This does not include crypto parts, nodes of alternative or related multipart nodes, or
+     * the primary body part (see textContent()).
+     * @see KMime::isAttachment(), KMime::hasAttachment()
+     */
+    QVector<Content*> attachments();
 
     /**
      * For multipart contents, this will return a list of all multipart child contents.
      * For contents that are of mimetype message/rfc822, this will return a list with one entry,
      * and that entry is the encapsulated message, as it would be returned by bodyAsMessage().
      */
-    List contents() const;
+    QVector<Content*> contents() const;
 
     /**
       Adds a new sub-Content. If the sub-Content is already part of another
@@ -645,56 +579,14 @@ public:
     */
     void changeEncoding(Headers::contentEncoding e);
 
-    /**
-      Saves the encoded Content to the given textstream
-
-      @param ts is the stream where the Content should be written to.
-      @param scrambleFromLines: If true, replace "\nFrom " with "\n>From "
-      in the stream. This is needed to avoid problem with mbox-files
-    */
-    void toStream(QTextStream &ts, bool scrambleFromLines = false);
-
-    // NOTE: The charset methods below are accessed by the headers which
-    // have this Content as a parent.
-
     /**
       Returns the charset that is used to decode RFC2047 strings in all headers and to decode
       the body if the charset is not declared explictly.
       It is also used as the charset when encoding RFC2047 strings in headers.
-
-      @see setDefaultCharset()
     */
     // TODO: Split this up into a charset for encoding and one for decoding, and make the one for
     //       encoding UTF-8 by default.
-    QByteArray defaultCharset() const;
-
-    /**
-      Sets the default charset.
-
-      @param cs is a QByteArray containing the new default charset.
-
-      @see defaultCharset().
-    */
-    void setDefaultCharset(const QByteArray &cs);
-
-    /**
-      Use the default charset even if a different charset is
-      declared in the article.
-
-      @see setForceDefaultCharset().
-    */
-    bool forceDefaultCharset() const;
-
-    /**
-      Enables/disables the force mode, housekeeping.
-      works correctly only when the article is completely empty or
-      completely loaded.
-
-      @param b If true, force the default charset to be used.
-
-      @see forceDefaultCharset().
-    */
-    virtual void setForceDefaultCharset(bool b);
+    static QByteArray defaultCharset();
 
     /**
       Returns the Content specified by the given index.
@@ -717,7 +609,7 @@ public:
       a Message or NewsArticle. However, a node can be a Message without being a top-level node when
       it is an encapsulated message.
     */
-    virtual bool isTopLevel() const;
+    bool isTopLevel() const;
 
     /**
      * Sets a new parent to the Content and add to its contents list. If it already had a parent, it is removed from the
@@ -773,7 +665,7 @@ public:
      * @since 4.5
      */
     //AK_REVIEW: move to MessageViewer/ObjectTreeParser
-    boost::shared_ptr<Message> bodyAsMessage() const;
+    QSharedPointer<Message> bodyAsMessage() const;
 
 protected:
     /**
@@ -783,41 +675,8 @@ protected:
     */
     virtual QByteArray assembleHeaders();
 
-    /**
-      Returns the raw string representing the header of type @p name.
-      @param name the header type to find
-      @deprecated Use KMime::extractHeader() directly instead.
-    */
-    KMIME_DEPRECATED QByteArray rawHeader(const char *name) const;
-
-    /**
-      Returns a list of raw strings representing all header of type @p name.
-      @deprecated Use KMime::extractHeaders() directly instead.
-    */
-    KMIME_DEPRECATED QList<QByteArray> rawHeaders(const char *name) const;
-
-    /**
-      Returns whether this object holds text content.
-    */
-    // KDE5: Not needed outside. Move to Private class.
-    bool decodeText();
-
-    /**
-      Returns the first header of type T, if it exists.
-      @deprecated Use header() instead.
-    */
-    template <class T> KMIME_DEPRECATED T *headerInstance(T *ptr, bool create);
-
-    /**
-      The list of headers in this Content.
-      Do not use this directly.
-    */
-    // KDE5: Not needed outside. Move to Private class.
-    Headers::Base::List h_eaders;
-
     //@cond PRIVATE
     ContentPrivate *d_ptr;
-    explicit Content(ContentPrivate *d);
     //@endcond
 
 private:
@@ -825,14 +684,6 @@ private:
     Q_DISABLE_COPY(Content)
 };
 
-// some compilers (for instance Compaq C++) need template inline functions
-// here rather than in the *.cpp file
-
-template <class T> T *Content::headerInstance(T* /*ptr*/, bool create)
-{
-    return header<T>(create);
-}
-
 template <typename T> T *Content::header(bool create)
 {
     Headers::Base *h = headerByType(T::staticType());
@@ -840,12 +691,19 @@ template <typename T> T *Content::header(bool create)
         // Make sure the header is actually of the right type.
         Q_ASSERT(dynamic_cast<T *>(h));
     } else if (create) {
-        h = new T(this);
-        setHeader(h);
+        h = new T;
+        appendHeader(h); // we already know the header doesn't exist yet
     }
     return static_cast<T *>(h);
 }
 
+template <typename T> bool Content::removeHeader()
+{
+    return removeHeader(T::staticType());
+}
+
 } // namespace KMime
 
+Q_DECLARE_METATYPE(KMime::Content*)
+
 #endif // __KMIME_CONTENT_H__
